"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployFunctions = void 0;
const infra_aws_1 = require("@goldstack/infra-aws");
const deployFunction_1 = require("./deployFunction");
const generateFunctionName_1 = require("./generate/generateFunctionName");
const utils_sh_1 = require("@goldstack/utils-sh");
const buildFunctions_1 = require("./buildFunctions");
const deployFunctions = async (params) => {
    const lambdaConfig = params.config; //readLambdaConfig(params.routesPath);
    const operations = lambdaConfig.map(async (config) => {
        const functionName = (0, generateFunctionName_1.generateFunctionName)(params.configuration.lambdaNamePrefix, config);
        console.log(`[${functionName}]: Starting deployment`);
        const functionDir = (0, buildFunctions_1.getOutDirForLambda)(config);
        (0, utils_sh_1.mkdir)('-p', functionDir);
        const targetArchive = `./distLambda/zips/${functionName}.zip`;
        await (0, deployFunction_1.deployFunction)({
            targetArchiveName: targetArchive,
            lambdaPackageDir: functionDir,
            awsCredentials: await (0, infra_aws_1.getAWSUser)(params.deployment.awsUser),
            region: params.deployment.awsRegion,
            functionName,
        });
        console.log(`[${functionName}]: Deployment completed`);
    });
    await Promise.all(operations);
};
exports.deployFunctions = deployFunctions;
//# sourceMappingURL=deployFunctions.js.map